@@ -39,12 +39,13 @@ except NameError:
 
 try:
     version = pkg_resources.get_distribution("ansible_runner").version
-    backward_compat = (version < '1.4.4')
+    BACKWARD_COMPAT = (version < '1.4.0')
 except pkg_resources.DistributionNotFound:
-    backward_compat = False
+    BACKWARD_COMPAT = False
 
 
 class Ansible(object):
+    """An Object for encapsulating an Ansible execution"""
 
     def __init__(self, uuid=None):
         self.log = logging.getLogger(__name__ + ".Ansible")
@@ -65,7 +66,7 @@ class Ansible(object):
             if isinstance(inventory, six.string_types):
                 # check is file path
                 if os.path.exists(inventory):
-                    return inventory
+                    return os.path.abspath(inventory)
             elif isinstance(inventory, dict):
                 inventory = yaml.safe_dump(
                     inventory,
@@ -78,16 +79,13 @@ class Ansible(object):
             )
 
     def _creates_ansible_fact_dir(self,
-                                  temp_suffix='validagions-libs-ansible'):
+                                  temp_suffix='validations-libs-ansible'):
         """Creates ansible fact dir"""
         ansible_fact_path = os.path.join(
-            os.path.join(
                 tempfile.gettempdir(),
-                temp_suffix
-            ),
-            'fact_cache'
-        )
-
+                temp_suffix,
+                'fact_cache'
+                )
         try:
             os.makedirs(ansible_fact_path)
             return ansible_fact_path
@@ -110,22 +108,26 @@ class Ansible(object):
                     extravars.update(yaml.safe_load(f.read()))
         return extravars
 
-    def _callback_whitelist(self, callback_whitelist, output_callback):
-        """Set callback whitelist"""
-        if callback_whitelist:
-            callback_whitelist = ','.join([callback_whitelist,
-                                          output_callback])
-        else:
-            callback_whitelist = output_callback
-        return ','.join([callback_whitelist, 'profile_tasks'])
+    def _callbacks(self, callback_whitelist, output_callback, envvars={},
+                   env={}):
+        """Set callbacks"""
+        # if output_callback is exported in env, then use it
+        if isinstance(envvars, dict):
+            env.update(envvars)
+        output_callback = env.get('ANSIBLE_STDOUT_CALLBACK', output_callback)
+        callback_whitelist = ','.join(filter(None, [callback_whitelist,
+                                                    output_callback,
+                                                    'validation_json',
+                                                    'profile_tasks']))
+        return callback_whitelist, output_callback
 
     def _ansible_env_var(self, output_callback, ssh_user, workdir, connection,
                          gathering_policy, module_path, key,
                          extra_env_variables, ansible_timeout,
-                         callback_whitelist, base_dir, python_interpreter):
+                         callback_whitelist, base_dir, python_interpreter,
+                         env={}):
         """Handle Ansible env var for Ansible config execution"""
         cwd = os.getcwd()
-        env = os.environ.copy()
         env['ANSIBLE_SSH_ARGS'] = (
             '-o UserKnownHostsFile={} '
             '-o StrictHostKeyChecking=no '
@@ -148,7 +150,8 @@ class Ansible(object):
         env['ANSIBLE_GATHER_TIMEOUT'] = 45
         env['ANSIBLE_SSH_RETRIES'] = 3
         env['ANSIBLE_PIPELINING'] = True
-        env['ANSIBLE_REMOTE_USER'] = ssh_user
+        if ssh_user:
+            env['ANSIBLE_REMOTE_USER'] = ssh_user
         env['ANSIBLE_STDOUT_CALLBACK'] = output_callback
         env['ANSIBLE_LIBRARY'] = os.path.expanduser(
             '~/.ansible/plugins/modules:'
@@ -273,9 +276,9 @@ class Ansible(object):
             return env
 
     def run(self, playbook, inventory, workdir, playbook_dir=None,
-            connection='smart', output_callback='yaml',
+            connection='smart', output_callback=None,
             base_dir=constants.DEFAULT_VALIDATIONS_BASEDIR,
-            ssh_user='root', key=None, module_path=None,
+            ssh_user=None, key=None, module_path=None,
             limit_hosts=None, tags=None, skip_tags=None,
             verbosity=0, quiet=False, extra_vars=None,
             gathering_policy='smart',
@@ -283,10 +286,95 @@ class Ansible(object):
             callback_whitelist=None, ansible_cfg=None,
             ansible_timeout=30, ansible_artifact_path=None,
             log_path=None, run_async=False, python_interpreter=None):
+        """Execute one or multiple Ansible playbooks
 
+        :param playbook: The Absolute path of the Ansible playbook
+        :type playbook: ``string``
+        :param inventory: Either proper inventory file or a
+                          comma-separated list
+        :type inventory: ``string``
+        :param workdir: The absolute path of the Ansible-runner
+                        artifacts directory
+        :type workdir: ``string``
+        :param playbook_dir: The absolute path of the Validations playbooks
+                             directory
+        :type playbook_dir: ``string``
+        :param connection: Connection type (local, smart, etc).
+                        (efaults to 'smart')
+        :type connection: String
+        :param output_callback: Callback for output format. Defaults to
+                                'yaml'.
+        :type output_callback: ``string``
+        :param base_dir: The absolute path of the default validations base
+                         directory
+        :type base_dir: ``string``
+        :param ssh_user: User for the ssh connection (Defaults to 'root')
+        :type ssh_user: ``string``
+        :param key: Private key to use for the ssh connection.
+        :type key: ``string``
+        :param module_path: Location of the ansible module and library.
+        :type module_path: ``string``
+        :param limit_hosts: Limit the execution to the hosts.
+        :type limit_hosts: ``string``
+        :param tags: Run specific tags.
+        :type tags: ``string``
+        :param skip_tags: Skip specific tags.
+        :type skip_tags: ``string``
+        :param verbosity: Verbosity level for Ansible execution.
+        :type verbosity: ``integer``
+        :param quiet: Disable all output (Defaults to False)
+        :type quiet: ``boolean``
+        :param extra_vars: Set additional variables as a Dict or the absolute
+                        path of a JSON or YAML file type.
+        :type extra_vars: Either a Dict or the absolute path of JSON or YAML
+        :param gathering_policy: This setting controls the default policy of
+                        fact gathering ('smart', 'implicit', 'explicit').
+                        (Defaults to 'smart')
+        :type gathering_facts: ``string``
+        :param extra_env_vars: Set additional ansible variables using an
+                                extravar dictionary.
+        :type extra_env_vars: ``dict``
+        :param parallel_run: Isolate playbook execution when playbooks are
+                             to be executed with multi-processing.
+        :type parallel_run: ``boolean``
+        :param callback_whitelist: Comma separated list of callback plugins.
+                                Custom output_callback is also whitelisted.
+                                (Defaults to ``None``)
+        :type callback_whitelist: ``list`` or ``string``
+        :param ansible_cfg: Path to an ansible configuration file. One will be
+                         generated in the artifact path if this option is None.
+        :type ansible_cfg: ``string``
+        :param ansible_timeout: Timeout for ansible connections.
+                                (Defaults to ``30 minutes``)
+        :type ansible_timeout: ``integer``
+        :param ansible_artifact_path: The Ansible artifact path
+        :type ansible_artifact_path: ``string``
+        :param log_path: The absolute path of the validations logs directory
+        :type log_path: ``string``
+        :param run_async: Enable the Ansible asynchronous mode
+                          (Defaults to 'False')
+        :type run_async: ``boolean``
+        :param python_interpreter: Path to the Python interpreter to be
+                                   used for module execution on remote targets,
+                                   or an automatic discovery mode (``auto``,
+                                   ``auto_silent`` or the default one
+                                   ``auto_legacy``)
+        :type python_interpreter: ``string``
+
+        :return: A ``tuple`` containing the the absolute path of the executed
+                 playbook, the return code and the status of the run
+        :rtype: ``tuple``
+        """
         if not playbook_dir:
             playbook_dir = workdir
 
+        if not ansible_artifact_path:
+            if log_path:
+                ansible_artifact_path = "{}/artifacts/".format(log_path)
+            else:
+                ansible_artifact_path = \
+                    constants.VALIDATION_ANSIBLE_ARTIFACT_PATH
+
         playbook = self._playbook_check(playbook, playbook_dir)
         self.log.info(
             'Running Ansible playbook: {},'
@@ -298,19 +386,25 @@ class Ansible(object):
             )
         )
 
-        # ansible_fact_path = self._creates_ansible_fact_dir()
+        # Get env variables:
+        env = {}
+        env = os.environ.copy()
         extravars = self._get_extra_vars(extra_vars)
-        callback_whitelist = self._callback_whitelist(callback_whitelist,
-                                                      output_callback)
 
+        if isinstance(callback_whitelist, list):
+            callback_whitelist = ','.join(callback_whitelist)
+        callback_whitelist, output_callback = self._callbacks(
+            callback_whitelist,
+            output_callback,
+            extra_env_variables,
+            env)
         # Set ansible environment variables
-        env = self._ansible_env_var(output_callback, ssh_user, workdir,
-                                    connection, gathering_policy, module_path,
-                                    key, extra_env_variables, ansible_timeout,
-                                    callback_whitelist, base_dir,
-                                    python_interpreter)
-        if not ansible_artifact_path:
-            ansible_artifact_path = constants.VALIDATION_ANSIBLE_ARTIFACT_PATH
+        env.update(self._ansible_env_var(output_callback, ssh_user, workdir,
+                                         connection, gathering_policy,
+                                         module_path, key, extra_env_variables,
+                                         ansible_timeout, callback_whitelist,
+                                         base_dir, python_interpreter))
+
         if 'ANSIBLE_CONFIG' not in env and not ansible_cfg:
             ansible_cfg = os.path.join(ansible_artifact_path, 'ansible.cfg')
             config = configparser.ConfigParser()
@@ -338,7 +432,7 @@ class Ansible(object):
             'ident': ''
             }
 
-        if not backward_compat:
+        if not BACKWARD_COMPAT:
             r_opts.update({
                 'envvars': envvars,
                 'project_dir': playbook_dir,
@@ -363,7 +457,7 @@ class Ansible(object):
         runner_config.prepare()
         runner_config.env['ANSIBLE_STDOUT_CALLBACK'] = \
             envvars['ANSIBLE_STDOUT_CALLBACK']
-        if backward_compat:
+        if BACKWARD_COMPAT:
             runner_config.env.update(envvars)
 
         runner = ansible_runner.Runner(config=runner_config)
