@@ -27,6 +27,19 @@ VALIDATIONS_LIST = [{
     'parameters': {'min_value': 8}
 }]
 
+VALIDATIONS_LIST_GROUP = [{
+    'description': 'My Validation Two Description',
+    'groups': ['prep', 'pre-introspection'],
+    'id': 'my_val2',
+    'name': 'My Validation Two Name',
+    'parameters': {'min_value': 8}
+}]
+
+
+VALIDATION_LIST_RESULT = (('ID', 'Name', 'Groups'),
+                          [('my_val2', 'My Validation Two Name',
+                            ['prep', 'pre-introspection'])])
+
 GROUPS_LIST = [
     ('group1', 'Group1 description'),
     ('group2', 'Group2 description'),
@@ -50,9 +63,36 @@ BAD_VALIDATIONS_LOGS_CONTENTS_LIST = [{
             'changed': 0,
             'failures': 0,
             'ignored': 0,
-            'ok': 1,
+            'ok': 0,
             'rescued': 0,
-            'skipped': 1
+            'skipped': 0,
+            'unreachable': 1
+        }
+    },
+    'validation_output': []
+}]
+
+FAILED_VALIDATIONS_LOGS_CONTENTS_LIST = [{
+    'plays': [{
+        'play': {
+            'duration': {
+                'end': '2019-11-25T13:40:17.538611Z',
+            },
+            'host': 'undercloud',
+            'id': '008886df-d297-1eaa-2a74-000000000008',
+            'validation_id': '512e',
+            'validation_path':
+            '/usr/share/openstack-tripleo-validations/playbooks'
+            }}],
+    'stats': {
+        'undercloud': {
+            'changed': 0,
+            'failures': 1,
+            'ignored': 0,
+            'ok': 0,
+            'rescued': 0,
+            'skipped': 0,
+            'unreachable': 0
         }
     },
     'validation_output': []
@@ -174,6 +214,18 @@ VALIDATIONS_DATA = {'Description': 'My Validation One Description',
 VALIDATIONS_STATS = {'Last execution date': '2019-11-25 13:40:14',
                      'Number of execution': 'Total: 1, Passed: 0, Failed: 1'}
 
+FAKE_WRONG_PLAYBOOK = [{
+    'hosts': 'undercloud',
+    'roles': ['advanced_format_512e_support'],
+    'vars': {
+        'nometadata': {
+            'description': 'foo',
+            'groups': ['prep', 'pre-deployment'],
+            'name': 'Advanced Format 512e Support'
+        }
+    }
+}]
+
 FAKE_PLAYBOOK = [{'hosts': 'undercloud',
                   'roles': ['advanced_format_512e_support'],
                   'vars': {'metadata': {'description': 'foo',
@@ -189,6 +241,14 @@ FAKE_PLAYBOOK2 = [{'hosts': 'undercloud',
                                          'Advanced Format 512e Support'},
                             'foo': 'bar'}}]
 
+FAKE_PLAYBOOK3 = [{'hosts': 'undercloud',
+                   'roles': ['advanced_format_512e_support'],
+                   'vars': {'metadata': {'description': 'foo',
+                                         'name':
+                                         'Advanced Format 512e Support'},
+                            'foo': 'bar'}}]
+
+FAKE_VARS = {'foo': 'bar'}
 
 FAKE_METADATA = {'id': 'foo',
                  'description': 'foo',
@@ -205,6 +265,36 @@ GROUP = {'no-op': [{'description': 'noop-foo'}],
          'pre': [{'description': 'pre-foo'}],
          'post': [{'description': 'post-foo'}]}
 
+FAKE_SUCCESS_RUN = [{'Duration': '0:00:01.761',
+                     'Host_Group': 'overcloud',
+                     'Status': 'PASSED',
+                     'Status_by_Host': 'subnode-1,PASSED, subnode-2,PASSED',
+                     'UUID': '123',
+                     'Unreachable_Hosts': '',
+                     'Validations': 'foo'}]
+
+FAKE_FAILED_RUN = [{'Duration': '0:00:01.761',
+                    'Host_Group': 'overcloud',
+                    'Status': 'FAILED',
+                    'Status_by_Host': 'subnode-1,FAILED, subnode-2,PASSED',
+                    'UUID': '123',
+                    'Unreachable_Hosts': '',
+                    'Validations': 'foo'},
+                   {'Duration': '0:00:01.761',
+                    'Host_Group': 'overcloud',
+                    'Status': 'FAILED',
+                    'Status_by_Host': 'subnode-1,FAILED, subnode-2,PASSED',
+                    'UUID': '123',
+                    'Unreachable_Hosts': '',
+                    'Validations': 'foo'},
+                   {'Duration': '0:00:01.761',
+                    'Host_Group': 'overcloud',
+                    'Status': 'PASSED',
+                    'Status_by_Host': 'subnode-1,PASSED, subnode-2,PASSED',
+                    'UUID': '123',
+                    'Unreachable_Hosts': '',
+                    'Validations': 'foo'}]
+
 
 def fake_ansible_runner_run_return(status='successful', rc=0):
     return status, rc
